{namespace neos=TYPO3\Neos\ViewHelpers}
{namespace media=TYPO3\Media\ViewHelpers}
<section class="clients">
	<div class="container">
		<div class="row">
			<div class="col-sm-12 text-center">
				{neos:contentElement.editable(property: 'lead', class: 'lead', tag: 'p')}
			</div>
		</div>

		<div class="row client-row">
			<div class="row-wrapper">
				<div class="col-sm-3 text-center">
					<f:if condition="{clientImage1.properties.image}">
						<f:then>
							<neos:contentElement.wrap node="{clientImage1}">
								<figure>
									<media:image asset="{clientImage1.properties.image}" alt="{title}" title="{title}" maximumWidth="500" allowCropping="1" allowUpScaling="1"/>
								</figure>
							</neos:contentElement.wrap>
						</f:then>
						<f:else>
							<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
								<neos:contentElement.wrap node="{clientImage1}">
									<figure>
										<f:if condition="{node.context.workspace.name} != 'live'">
											<img src="{f:uri.resource(package: 'TYPO3.Neos', path: 'Images/dummy-image.svg')}"
												 title="Dummy image" alt="Dummy image"/>
										</f:if>
									</figure>
								</neos:contentElement.wrap>
							</f:security.ifAccess>
						</f:else>
					</f:if>
				</div>

				<div class="col-sm-3 text-center">
					<f:if condition="{clientImage2.properties.image}">
						<f:then>
							<neos:contentElement.wrap node="{clientImage2}">
								<figure>
									<media:image asset="{clientImage2.properties.image}" alt="{title}" title="{title}" maximumWidth="500" allowCropping="1" allowUpScaling="1"/>
								</figure>
							</neos:contentElement.wrap>
						</f:then>
						<f:else>
							<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
								<neos:contentElement.wrap node="{clientImage2}">
									<figure>
										<f:if condition="{node.context.workspace.name} != 'live'">
											<img src="{f:uri.resource(package: 'TYPO3.Neos', path: 'Images/dummy-image.svg')}"
												 title="Dummy image" alt="Dummy image"/>
										</f:if>
									</figure>
								</neos:contentElement.wrap>
							</f:security.ifAccess>
						</f:else>
					</f:if>
				</div>

				<div class="col-sm-3 text-center">
					<f:if condition="{clientImage3.properties.image}">
						<f:then>
							<neos:contentElement.wrap node="{clientImage3}">
								<figure>
									<media:image asset="{clientImage3.properties.image}" alt="{title}" title="{title}" maximumWidth="500" allowCropping="1" allowUpScaling="1"/>
								</figure>
							</neos:contentElement.wrap>
						</f:then>
						<f:else>
							<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
								<neos:contentElement.wrap node="{clientImage3}">
									<figure>
										<f:if condition="{node.context.workspace.name} != 'live'">
											<img src="{f:uri.resource(package: 'TYPO3.Neos', path: 'Images/dummy-image.svg')}"
												 title="Dummy image" alt="Dummy image"/>
										</f:if>
									</figure>
								</neos:contentElement.wrap>
							</f:security.ifAccess>
						</f:else>
					</f:if>
				</div>

				<div class="col-sm-3 text-center">
					<f:if condition="{clientImage4.properties.image}">
						<f:then>
							<neos:contentElement.wrap node="{clientImage4}">
								<figure>
									<media:image asset="{clientImage4.properties.image}" alt="{title}" title="{title}" maximumWidth="500" allowCropping="1" allowUpScaling="1"/>
								</figure>
							</neos:contentElement.wrap>
						</f:then>
						<f:else>
							<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
								<neos:contentElement.wrap node="{clientImage4}">
									<figure>
										<f:if condition="{node.context.workspace.name} != 'live'">
											<img src="{f:uri.resource(package: 'TYPO3.Neos', path: 'Images/dummy-image.svg')}"
												 title="Dummy image" alt="Dummy image"/>
										</f:if>
									</figure>
								</neos:contentElement.wrap>
							</f:security.ifAccess>
						</f:else>
					</f:if>
				</div>
			</div>
		</div>

		<div class="row client-row">
			<div class="row-wrapper">
				<div class="col-sm-3 text-center">
					<f:if condition="{clientImage5.properties.image}">
						<f:then>
							<neos:contentElement.wrap node="{clientImage5}">
								<figure>
									<media:image asset="{clientImage5.properties.image}" alt="{title}" title="{title}" maximumWidth="500" allowCropping="1" allowUpScaling="1"/>
								</figure>
							</neos:contentElement.wrap>
						</f:then>
						<f:else>
							<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
								<neos:contentElement.wrap node="{clientImage5}">
									<figure>
										<f:if condition="{node.context.workspace.name} != 'live'">
											<img src="{f:uri.resource(package: 'TYPO3.Neos', path: 'Images/dummy-image.svg')}"
												 title="Dummy image" alt="Dummy image"/>
										</f:if>
									</figure>
								</neos:contentElement.wrap>
							</f:security.ifAccess>
						</f:else>
					</f:if>
				</div>

				<div class="col-sm-3 text-center">
					<f:if condition="{clientImage6.properties.image}">
						<f:then>
							<neos:contentElement.wrap node="{clientImage6}">
								<figure>
									<media:image asset="{clientImage6.properties.image}" alt="{title}" title="{title}" maximumWidth="500" allowCropping="1" allowUpScaling="1"/>
								</figure>
							</neos:contentElement.wrap>
						</f:then>
						<f:else>
							<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
								<neos:contentElement.wrap node="{clientImage6}">
									<figure>
										<f:if condition="{node.context.workspace.name} != 'live'">
											<img src="{f:uri.resource(package: 'TYPO3.Neos', path: 'Images/dummy-image.svg')}"
												 title="Dummy image" alt="Dummy image"/>
										</f:if>
									</figure>
								</neos:contentElement.wrap>
							</f:security.ifAccess>
						</f:else>
					</f:if>
				</div>

				<div class="col-sm-3 text-center">
					<f:if condition="{clientImage7.properties.image}">
						<f:then>
							<neos:contentElement.wrap node="{clientImage7}">
								<figure>
									<media:image asset="{clientImage7.properties.image}" alt="{title}" title="{title}" maximumWidth="500" allowCropping="1" allowUpScaling="1"/>
								</figure>
							</neos:contentElement.wrap>
						</f:then>
						<f:else>
							<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
								<neos:contentElement.wrap node="{clientImage7}">
									<figure>
										<f:if condition="{node.context.workspace.name} != 'live'">
											<img src="{f:uri.resource(package: 'TYPO3.Neos', path: 'Images/dummy-image.svg')}"
												 title="Dummy image" alt="Dummy image"/>
										</f:if>
									</figure>
								</neos:contentElement.wrap>
							</f:security.ifAccess>
						</f:else>
					</f:if>
				</div>

				<div class="col-sm-3 text-center">
					<f:if condition="{clientImage8.properties.image}">
						<f:then>
							<neos:contentElement.wrap node="{clientImage8}">
								<figure>
									<media:image asset="{clientImage8.properties.image}" alt="{title}" title="{title}" maximumWidth="500" allowCropping="1" allowUpScaling="1"/>
								</figure>
							</neos:contentElement.wrap>
						</f:then>
						<f:else>
							<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
								<neos:contentElement.wrap node="{clientImage8}">
									<figure>
										<f:if condition="{node.context.workspace.name} != 'live'">
											<img src="{f:uri.resource(package: 'TYPO3.Neos', path: 'Images/dummy-image.svg')}"
												 title="Dummy image" alt="Dummy image"/>
										</f:if>
									</figure>
								</neos:contentElement.wrap>
							</f:security.ifAccess>
						</f:else>
					</f:if>
				</div>
			</div>
		</div>
	</div>
</section>
