{namespace neos=TYPO3\Neos\ViewHelpers}
<link rel="shortcut icon" href="/favicon.ico">

<meta name="description" content="">
<meta name="viewport" content="width=device-width, initial-scale=1">
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<link href='http://fonts.googleapis.com/css?family=Open+Sans:300italic,400italic,400,300,600,700%7CRaleway:700' rel='stylesheet' type='text/css'>
<script src="{f:uri.resource(path: 'js/modernizr-2.6.2-respond-1.1.0.min.js', package: 'MOC.Pivot')}"></script>