{namespace neos=TYPO3\Neos\ViewHelpers}
<section class="team-1">
	<div class="container">
		<div class="row">
			<div class="col-md-8 col-md-offset-2 text-center">
				{neos:contentElement.editable(property: 'title', tag: 'h1')}
				{neos:contentElement.editable(property: 'lead', class: 'lead')}
			</div>
		</div>

		<div class="row">
			{employees -> f:format.raw()}
		</div>

	</div>
</section>