{namespace neos=TYPO3\Neos\ViewHelpers}
{namespace media=TYPO3\Media\ViewHelpers}
<header class="page-header {backgroundColor} {f:if(condition: top, then: 'top')}">
	<div class="background-image-holder parallax-background">
		<f:if condition="{image}">
			<media:image asset="{image}" alt="Background Image" class="background-image" maximumWidth="2000" maximumHeight="1500" allowCropping="1" allowUpScaling="1" />
		</f:if>
	</div>

	<div class="container">
		<div class="row">
			<div class="col-sm-12{f:if(condition: centered, then: ' text-center')}">
				{neos:contentElement.editable(property: 'intro', class: 'alt-font {fontColor}', tag: 'span')}
				{neos:contentElement.editable(property: 'title', class: '{fontColor}', tag: 'h1')}
				{neos:contentElement.editable(property: 'lead', class: 'lead {fontColor}', tag: 'p')}
			</div>
		</div>
	</div>
</header>