{namespace neos=TYPO3\Neos\ViewHelpers}
<nav class="top-bar simple-bar">
	<div class="container">


		<div class="row nav-menu">
			<div class="col-md-3 col-sm-3 columns">
				<neos:link.node node="~">
					<img class="logo logo-light" alt="Logo" src="{f:uri.resource(path: '{settings.logoLight}')}">
					<img class="logo logo-dark" alt="Logo" src="{f:uri.resource(path: '{settings.logoDark}')}">
				</neos:link.node>
			</div>

			<div class="col-md-9 col-sm-9 columns text-right">
				{menu -> f:format.raw()}
				{socialIcons -> f:format.raw()}
			</div>
		</div>

		<div class="mobile-toggle">
			<i class="icon icon_menu"></i>
		</div>

	</div>
</nav>