{namespace neos=TYPO3\Neos\ViewHelpers}
<section class="strip bg-secondary-1">
	<div class="container">
		<div class="row clearfix">
			<div class="col-sm-6 col-xs-12 pull-left">
				{neos:contentElement.editable(property: 'title', class: 'text-white', tag: 'h3')}
			</div>
			<div class="col-sm-4 col-xs-12 pull-right text-right">
				<f:if condition="{link}">
					<{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a href="{link}"', else: 'span')} class="btn btn-primary btn-white">
						{neos:contentElement.editable(property: 'linkText')}
					<{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a', else: 'span')}>
				</f:if>
			</div>
		</div>
	</div>
</section>