{namespace neos=TYPO3\Neos\ViewHelpers}
<section class="instagram-feed">
	<div class="container">
		<div class="row text-center">
			<div>{neos:contentElement.editable(property: 'lead', class: 'alt-font', tag: 'span')}</div>
		</div>
	</div>

	<div class="instafeed" data-user-name="{instagramId}">
		<ul></ul>
	</div>
</section>
