{namespace neos=TYPO3\Neos\ViewHelpers}
<div class="col-sm-6">
	<div class="feature feature-icon-large">
		<div class="pull-right">
			{neos:contentElement.editable(property: 'title', tag: 'h5')}
			{neos:contentElement.editable(property: 'text')}
		</div>
	</div>
</div>