<?php
namespace MOC\Pivot\MailObfuscator;

class RewriteAtCharConverter implements \Networkteam\Neos\MailObfuscator\String\Converter\EmailLinkNameConverterInterface {

	/**
	 * @param string $emailAddress
	 * @return string
	 */
	public function convert($emailAddress) {
		return str_replace('@', '&#x40;<span class="hidden">_</span>', $emailAddress);
	}
}