{namespace neos=TYPO3\Neos\ViewHelpers}
{namespace media=TYPO3\Media\ViewHelpers}
<section class="no-pad clearfix imageboxes">
	<div class="col-md-6 col-sm-12 no-pad">
		<div class="feature-box {backgroundColor1}">
			<div class="background-image-holder overlay">
				<f:if condition="{image1}">
					<media:image asset="{image1}" alt="Background Image" class="background-image" maximumWidth="1000" maximumHeight="1000" allowCropping="1" allowUpScaling="1" />
				</f:if>
			</div>

			<div class="inner">
				{neos:contentElement.editable(property: 'lead1', class: 'alt-font {fontColor1}', tag: 'span')}
				{neos:contentElement.editable(property: 'title1', class: '{fontColor1}', tag: '{title1Tag}')}
				{neos:contentElement.editable(property: 'text1', class: '{fontColor1}')}
				<f:if condition="{link1}">
					<{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a href="{link1}"', else: 'span')} class="btn btn-primary btn-white">
					{neos:contentElement.editable(property: 'link1Text')}
				</{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a', else: 'span')}>
				</f:if>
			</div>
		</div>
	</div>
	<div class="col-md-6 col-sm-12 no-pad">
		<div class="feature-box {backgroundColor2}">
			<div class="background-image-holder overlay">
				<f:if condition="{image2}">
					<media:image asset="{image2}" alt="Background Image" class="background-image" maximumWidth="1000" maximumHeight="1000" allowCropping="1" allowUpScaling="1" />
				</f:if>
			</div>

			<div class="inner">
				{neos:contentElement.editable(property: 'lead2', class: 'alt-font {fontColor2}', tag: 'span')}
				{neos:contentElement.editable(property: 'title2', class: '{fontColor2}', tag: '{title2Tag}')}
				{neos:contentElement.editable(property: 'text2', class: '{fontColor2}')}
				<f:if condition="{link2}">
					<{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a href="{link2}"', else: 'span')} class="btn btn-primary btn-white">
						{neos:contentElement.editable(property: 'link2Text')}
					</{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a', else: 'span')}>
				</f:if>
			</div>
		</div>
	</div>
</section>
